@@ -132,9 +132,6 @@
 */
 #define KVI_DEPRECATED
 
-#ifdef COMPILE_USE_QT4
-	#define debug tqDebug
-#endif
 
 
 #endif //_KVI_SETTINGS_H_
