@@ -36,24 +36,24 @@
 	KviTalListView::KviTalListView(TQWidget * pParent)
 	: TQListView(pParent)
 	{
-		connect(this,TQT_SIGNAL(selectionChanged(TQListViewItem *)),this,TQT_SLOT(redirect_selectionChanged(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(currentChanged(TQListViewItem *)),this,TQT_SLOT(redirect_currentChanged(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(clicked(TQListViewItem *)),this,TQT_SLOT(redirect_clicked(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(clicked(TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(redirect_clicked(TQListViewItem *,const TQPoint &,int)));
-		connect(this,TQT_SIGNAL(pressed(TQListViewItem *)),this,TQT_SLOT(redirect_pressed(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(pressed(TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(redirect_pressed(TQListViewItem *,const TQPoint &,int)));
-		connect(this,TQT_SIGNAL(doubleClicked(TQListViewItem *)),this,TQT_SLOT(redirect_doubleClicked(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(redirect_doubleClicked(TQListViewItem *,const TQPoint &,int)));
-		connect(this,TQT_SIGNAL(returnPressed(TQListViewItem *)),this,TQT_SLOT(redirect_returnPressed(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(spacePressed(TQListViewItem *)),this,TQT_SLOT(redirect_spacePressed(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(rightButtonClicked(TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(redirect_rightButtonClicked(TQListViewItem *,const TQPoint &,int)));
-		connect(this,TQT_SIGNAL(rightButtonPressed(TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(redirect_rightButtonPressed(TQListViewItem *,const TQPoint &,int)));
-		connect(this,TQT_SIGNAL(mouseButtonClicked(int,TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(redirect_mouseButtonClicked(int,TQListViewItem *,const TQPoint &,int)));
-		connect(this,TQT_SIGNAL(mouseButtonPressed(int,TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(redirect_mouseButtonPressed(int,TQListViewItem *,const TQPoint &,int)));
-		connect(this,TQT_SIGNAL(contextMenuRequested(TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(redirect_contextMenuRequested(TQListViewItem *,const TQPoint &,int)));
-		connect(this,TQT_SIGNAL(onItem(TQListViewItem *)),this,TQT_SLOT(redirect_onItem(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(expanded(TQListViewItem *)),this,TQT_SLOT(redirect_expanded(TQListViewItem *)));
-		connect(this,TQT_SIGNAL(collapsed(TQListViewItem *)),this,TQT_SLOT(redirect_collapsed(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(selectionChanged(TQListViewItem *)),this,TQ_SLOT(redirect_selectionChanged(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(currentChanged(TQListViewItem *)),this,TQ_SLOT(redirect_currentChanged(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(clicked(TQListViewItem *)),this,TQ_SLOT(redirect_clicked(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(clicked(TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(redirect_clicked(TQListViewItem *,const TQPoint &,int)));
+		connect(this,TQ_SIGNAL(pressed(TQListViewItem *)),this,TQ_SLOT(redirect_pressed(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(pressed(TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(redirect_pressed(TQListViewItem *,const TQPoint &,int)));
+		connect(this,TQ_SIGNAL(doubleClicked(TQListViewItem *)),this,TQ_SLOT(redirect_doubleClicked(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(redirect_doubleClicked(TQListViewItem *,const TQPoint &,int)));
+		connect(this,TQ_SIGNAL(returnPressed(TQListViewItem *)),this,TQ_SLOT(redirect_returnPressed(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(spacePressed(TQListViewItem *)),this,TQ_SLOT(redirect_spacePressed(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(rightButtonClicked(TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(redirect_rightButtonClicked(TQListViewItem *,const TQPoint &,int)));
+		connect(this,TQ_SIGNAL(rightButtonPressed(TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(redirect_rightButtonPressed(TQListViewItem *,const TQPoint &,int)));
+		connect(this,TQ_SIGNAL(mouseButtonClicked(int,TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(redirect_mouseButtonClicked(int,TQListViewItem *,const TQPoint &,int)));
+		connect(this,TQ_SIGNAL(mouseButtonPressed(int,TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(redirect_mouseButtonPressed(int,TQListViewItem *,const TQPoint &,int)));
+		connect(this,TQ_SIGNAL(contextMenuRequested(TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(redirect_contextMenuRequested(TQListViewItem *,const TQPoint &,int)));
+		connect(this,TQ_SIGNAL(onItem(TQListViewItem *)),this,TQ_SLOT(redirect_onItem(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(expanded(TQListViewItem *)),this,TQ_SLOT(redirect_expanded(TQListViewItem *)));
+		connect(this,TQ_SIGNAL(collapsed(TQListViewItem *)),this,TQ_SLOT(redirect_collapsed(TQListViewItem *)));
 	}
 
 	void KviTalListView::redirect_selectionChanged(TQListViewItem * pItem)
@@ -691,7 +691,7 @@
 		if(!parentControl)
 		    x += 3;
 		if ( !pixmap( 0 ) ) {
-		    lv->style().tqdrawPrimitive(TQStyle::PE_CheckListController, p,
+		    lv->style().drawPrimitive(TQStyle::PE_CheckListController, p,
 					  TQRect(x, 0, boxsize,
 						fm.height() + 2 + marg),
 					  cg, styleflags, TQStyleOption(this));
@@ -709,12 +709,12 @@
 		    y = (fm.height() + 2 + marg - boxsize) / 2;
 	
 		if ( ( myType == CheckBox ) || ( myType == CheckBoxController ) ) {
-		    lv->style().tqdrawPrimitive(TQStyle::PE_CheckListIndicator, p,
+		    lv->style().drawPrimitive(TQStyle::PE_CheckListIndicator, p,
 					      TQRect(x, y, boxsize,
 						    fm.height() + 2 + marg),
 					      cg, styleflags, TQStyleOption(this));
 		} else { //radio button look
-		    lv->style().tqdrawPrimitive(TQStyle::PE_CheckListExclusiveIndicator,
+		    lv->style().drawPrimitive(TQStyle::PE_CheckListExclusiveIndicator,
 						      p, TQRect(x, y, boxsize,
 							       fm.height() + 2 + marg),
 						      cg, styleflags, TQStyleOption(this));
