@@ -38,11 +38,6 @@
 	#include <windows.h>
 #else //!COMPILE_ON_WINDOWS
 	#ifndef COMPILE_NO_X
-		#ifdef COMPILE_USE_QT4
-			// We need this to be included BEFORE X11/Xlib.h
-			// because of preprocessor constant collisions...
-			#include <tqcoreevent.h>
-		#endif
 		#include "kvi_xlib.h" // for XEvent
 	#endif //!COMPILE_NO_X
 #endif //!COMPILE_ON_WINDOWS
@@ -54,7 +49,7 @@
 		
 	class KVIRC_API KviIpcSentinel : public TQWidget
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 		KviIpcSentinel();
