@@ -127,7 +127,7 @@ void KviIrcConnectionTargetResolver::start(KviIrcConnectionTarget * t)
 		m_pStartTimer = 0;
 	}
 	m_pStartTimer = new TQTimer(this);
-	connect(m_pStartTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(asyncStartResolve()));
+	connect(m_pStartTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(asyncStartResolve()));
 
 	m_pTarget = t;
 
@@ -228,7 +228,7 @@ void KviIrcConnectionTargetResolver::lookupProxyHostname()
 			}
 	
 			m_pProxyDns = new KviDns();
-			connect(m_pProxyDns,TQT_SIGNAL(lookupDone(KviDns *)),this,TQT_SLOT(proxyLookupTerminated(KviDns *)));
+			connect(m_pProxyDns,TQ_SIGNAL(lookupDone(KviDns *)),this,TQ_SLOT(proxyLookupTerminated(KviDns *)));
 	
 			if(!m_pProxyDns->lookup(m_pTarget->proxy()->m_szHostname.ptr(),
 				m_pTarget->proxy()->isIpV6() ? KviDns::IpV6 : KviDns::IpV4))
@@ -345,8 +345,8 @@ void KviIrcConnectionTargetResolver::lookupServerHostname()
 				m_pServerDns = 0;
 			}
 			m_pServerDns = new KviDns();
-			connect(m_pServerDns,TQT_SIGNAL(lookupDone(KviDns *)),this,
-				TQT_SLOT(serverLookupTerminated(KviDns *)));
+			connect(m_pServerDns,TQ_SIGNAL(lookupDone(KviDns *)),this,
+				TQ_SLOT(serverLookupTerminated(KviDns *)));
 			if(!m_pServerDns->lookup(m_pTarget->server()->m_szHostname,
 				m_pTarget->server()->isIpV6() ? KviDns::IpV6 : KviDns::IpV4))
 			{
