@@ -37,9 +37,6 @@
 
 #include "kvi_out.h"
 
-#ifdef COMPILE_USE_QT4
-	#include <tq3mimefactory.h>
-#endif
 
 namespace KviKvsCoreSimpleCommands
 {
@@ -139,11 +136,7 @@ namespace KviKvsCoreSimpleCommands
 			TQString szOriginal = szTopic;
 	
 			TQString topik = szTopic;
-#ifdef COMPILE_USE_QT4
-			TQStringList pl = Q3MimeSourceFactory::defaultFactory()->filePath();
-#else
 			TQStringList pl = TQMimeSourceFactory::defaultFactory()->filePath();
-#endif
 
 			bool bLowCaseTried = false;
 			bool bFound = KviFileUtils::fileExists(szTopic);
