@@ -107,7 +107,7 @@ void KviKvsEventManager::init()
 {
 	if(KviKvsEventManager::instance())
 	{
-		debug("WARNING: Trying to create KviKvsEventManager twice!");
+		tqDebug("WARNING: Trying to create KviKvsEventManager twice!");
 		return;
 	}
 	(void) new KviKvsEventManager();
@@ -117,7 +117,7 @@ void KviKvsEventManager::done()
 {
 	if(!KviKvsEventManager::instance())
 	{
-		debug("WARNING: Trying to destroy the KviKvsEventManager twice!");
+		tqDebug("WARNING: Trying to destroy the KviKvsEventManager twice!");
 		return;
 	}
 	delete KviKvsEventManager::instance();
