@@ -33,7 +33,7 @@ class KviDataBuffer;
 
 class KVIRC_API KviMexLinkFilter : public TQObject, public KviModuleExtension
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviMexLinkFilter(KviModuleExtensionDescriptor * d);
