@@ -116,7 +116,7 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 	// Button box
 	m_pButtonBox = new KviTalHBox(this);
 	
-	m_pTopSplitter = new TQSplitter(Qt::Horizontal,m_pButtonBox);
+	m_pTopSplitter = new TQSplitter(TQt::Horizontal,m_pButtonBox);
 
 	m_pButtonBox->setStretchFactor(m_pTopSplitter,1);
 	
@@ -125,8 +125,8 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 	// Topic widget on the left
 	m_pTopicWidget = new KviTopicWidget(m_pTopSplitter,"topic_widget");
 
-	connect(m_pTopicWidget,TQT_SIGNAL(topicSelected(const TQString &)),
-		this,TQT_SLOT(topicSelected(const TQString &)));
+	connect(m_pTopicWidget,TQ_SIGNAL(topicSelected(const TQString &)),
+		this,TQ_SLOT(topicSelected(const TQString &)));
 	// mode label follows the topic widget
 	m_pModeWidget = new KviModeWidget(m_pTopSplitter,this,"mode_");
 	KviTalToolTip::add(m_pModeWidget,__tr2qs("Channel mode"));
@@ -134,16 +134,16 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 	createTextEncodingButton(m_pButtonContainer);
 
 	// Central splitter
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this);
+	m_pSplitter = new TQSplitter(TQt::Horizontal,this);
 		m_pSplitter->setName(name);
 	m_pSplitter->setOpaqueResize(false);
 	// Spitted vertially on the left
-	m_pVertSplitter = new TQSplitter(Qt::Vertical,m_pSplitter);
+	m_pVertSplitter = new TQSplitter(TQt::Vertical,m_pSplitter);
 	m_pVertSplitter->setOpaqueResize(false);
 	// With the IRC view over
 	m_pIrcView = new KviIrcView(m_pVertSplitter,lpFrm,this);
 		m_pIrcView->setName(name);
-	connect(m_pIrcView,TQT_SIGNAL(rightClicked()),this,TQT_SLOT(textViewRightClicked()));
+	connect(m_pIrcView,TQ_SIGNAL(rightClicked()),this,TQ_SLOT(textViewRightClicked()));
 	// And the double view (that may be unused)
 	m_pMessageView = 0;
 	// The userlist on the right
@@ -152,29 +152,29 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 	
 	// and the related buttons
 	m_pDoubleViewButton = createToolButton(m_pButtonContainer,"double_view_button",KVI_SMALLICON_HIDEDOUBLEVIEW,KVI_SMALLICON_SHOWDOUBLEVIEW,__tr2qs("Split View"),false);
-	connect(m_pDoubleViewButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleDoubleView()));
+	connect(m_pDoubleViewButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleDoubleView()));
 	
 	m_pListViewButton = new KviWindowToolPageButton(KVI_SMALLICON_HIDELISTVIEW,KVI_SMALLICON_SHOWLISTVIEW,__tr2qs("User List"),buttonContainer(),true,"list_view_button");
-	connect(m_pListViewButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleListView()));
+	connect(m_pListViewButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleListView()));
 	m_pBanEditorButton = new KviWindowToolPageButton(KVI_SMALLICON_UNBAN,KVI_SMALLICON_BAN,__tr2qs("Ban Editor"),buttonContainer(),false,"ban_editor_button");
-	connect(m_pBanEditorButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleBanEditor()));
+	connect(m_pBanEditorButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleBanEditor()));
 	
 	if(m_pConsole->connection()->serverInfo()->supportedListModes().contains('e'))
 	{
 		m_pBanExceptionEditorButton =new KviWindowToolPageButton(KVI_SMALLICON_BANUNEXCEPT,KVI_SMALLICON_BANEXCEPT,__tr2qs("Ban Exception Editor"),buttonContainer(),false,"ban_exception_editor_button");
-		connect(m_pBanExceptionEditorButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleBanExceptionEditor()));
+		connect(m_pBanExceptionEditorButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleBanExceptionEditor()));
 	} else {
 		m_pBanExceptionEditorButton=0;
 	}
 	if(m_pConsole->connection()->serverInfo()->supportedListModes().contains('I'))
 	{
 		m_pInviteEditorButton =new KviWindowToolPageButton(KVI_SMALLICON_INVITEUNEXCEPT,KVI_SMALLICON_INVITEEXCEPT,__tr2qs("Invite Exception Editor"),buttonContainer(),false,"invite_exception_editor_button");
-		connect(m_pInviteEditorButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleInviteEditor()));
+		connect(m_pInviteEditorButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleInviteEditor()));
 	} else {
 		m_pInviteEditorButton = 0;
 	}
 	m_pModeEditorButton = new KviWindowToolPageButton(KVI_SMALLICON_CHANMODEHIDE,KVI_SMALLICON_CHANMODE,__tr2qs("Mode Editor"),buttonContainer(),false,"mode_editor_button");
-	connect(m_pModeEditorButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleModeEditor()));
+	connect(m_pModeEditorButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleModeEditor()));
 	m_pModeEditor = 0;
 	
 #ifdef COMPILE_CRYPT_SUPPORT
@@ -189,7 +189,7 @@ KviChannel::KviChannel(KviFrame * lpFrm,KviConsole * lpConsole,const char * name
 	if(g_pIconManager->getBigIcon("kvi_horizontal_left.png"))
 		m_pHideToolsButton->setPixmap(*(g_pIconManager->getBigIcon("kvi_horizontal_left.png")));
 	
-	connect(m_pHideToolsButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleToolButtons()));
+	connect(m_pHideToolsButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleToolButtons()));
 	
 	m_pUserListView = new KviUserListView(m_pSplitter,m_pListViewButton,connection()->userDataBase(),this,
 								AVERAGE_CHANNEL_USERS,__tr2qs("User List"),"user_list_view");
@@ -358,7 +358,7 @@ void KviChannel::showDoubleView(bool bShow)
 		{
 			m_pMessageView->setPrivateBackgroundPixmap(*(m_privateBackground.pixmap()));
 		}
-		connect(m_pMessageView,TQT_SIGNAL(rightClicked()),this,TQT_SLOT(textViewRightClicked()));
+		connect(m_pMessageView,TQ_SIGNAL(rightClicked()),this,TQ_SLOT(textViewRightClicked()));
 		m_pMessageView->setMasterView(m_pIrcView);
 		m_pIrcView->splitMessagesTo(m_pMessageView);
 		m_pMessageView->show();
@@ -394,8 +394,8 @@ void KviChannel::toggleModeEditor()
 		resizeEvent(0);
 	} else {
 		m_pModeEditor = new KviModeEditor(m_pSplitter,m_pModeEditorButton,"mode_editor",console(),m_szChannelMode,m_szChannelKey,m_szChannelLimit.ptr());
-		connect(m_pModeEditor,TQT_SIGNAL(setMode(const char *)),this,TQT_SLOT(setMode(const char *)));
-		connect(m_pModeEditor,TQT_SIGNAL(done()),this,TQT_SLOT(modeSelectorDone()));
+		connect(m_pModeEditor,TQ_SIGNAL(setMode(const char *)),this,TQ_SLOT(setMode(const char *)));
+		connect(m_pModeEditor,TQ_SIGNAL(done()),this,TQ_SLOT(modeSelectorDone()));
 		m_pModeEditor->show();
 		//setFocusHandlerNoClass(m_pInput,m_pModeEditor,"TQLineEdit");
 		if(!m_pModeEditorButton->isOn())m_pModeEditorButton->setOn(true);
@@ -476,8 +476,8 @@ void KviChannel::toggleEditor(KviMaskEditor ** ppEd,KviWindowToolPageButton ** p
 		}
 
 		*ppEd = new KviMaskEditor(m_pSplitter,*ppBtn,l,flag,edName);
-		connect(*ppEd,TQT_SIGNAL(removeMasks(KviMaskEditor *,KviPointerList<KviMaskEntry> *)),
-			this,TQT_SLOT(removeMasks(KviMaskEditor *,KviPointerList<KviMaskEntry> *)));
+		connect(*ppEd,TQ_SIGNAL(removeMasks(KviMaskEditor *,KviPointerList<KviMaskEntry> *)),
+			this,TQ_SLOT(removeMasks(KviMaskEditor *,KviPointerList<KviMaskEntry> *)));
 		//setFocusHandler(m_pInput,*ppEd); //socket it!
 		(*ppEd)->show();
 		if(!(*ppBtn))return;
