@@ -33,7 +33,7 @@
 
 class KVIRC_API KviModeWidget : public TQFrame 
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 public:
