@@ -64,12 +64,7 @@
 #include <tqevent.h>
 
 // it looks they can't decide :D
-#ifdef COMPILE_USE_QT4
-	#include <TQPushButton>
-	#include <tqdesktopwidget.h>
-#else
         #include <tqobjectlist.h>
-#endif
 
 
 #include <tqvariant.h>
@@ -144,15 +139,10 @@ KviWindow::KviWindow(int type,KviFrame * lpFrm,const TQString &name,KviConsole *
 	m_pTaskBarItem = 0;
 
 	setMinimumSize(KVI_WINDOW_MIN_WIDTH,KVI_WINDOW_MIN_HEIGHT);
-#ifdef COMPILE_USE_QT4
-	//setAutoFillBackground(false);
-	setFocusPolicy(TQ_StrongFocus);
-#else
 	setBackgroundMode(NoBackground);
-	setFocusPolicy(TQ_StrongFocus);
-#endif
+	setFocusPolicy(TQWidget::StrongFocus);
 	
-	connect(g_pApp,TQT_SIGNAL(reloadImages()),this,TQT_SLOT(reloadImages()));
+	connect(g_pApp,TQ_SIGNAL(reloadImages()),this,TQ_SLOT(reloadImages()));
 }
 
 KviWindow::~KviWindow()
@@ -227,8 +217,8 @@ bool KviWindow::hasAttention()
 		// KVIrc window just below and can see it.
 
 		// Handle the special case of the dialogs then
-		TQWidget * w = TQT_TQWIDGET(((TQApplication *)g_pApp)->activeWindow());
-		if(w->inherits(TQDIALOG_OBJECT_NAME_STRING))
+		TQWidget * w = ((TQApplication *)g_pApp)->activeWindow();
+		if(w->inherits("TQDialog"))
 		{
 			// but make sure that the frame is visible at all!
 			if(!frame()->isVisible())return false;
@@ -288,21 +278,13 @@ bool KviWindow::focusNextPrevChild(bool next)
 	TQWidget * w = focusWidget();
 	if(w)
 	{
-#ifdef COMPILE_USE_QT4
-		if(w->focusPolicy() == TQ_StrongFocus)return false;
-#else
-		if(w->focusPolicy() == TQ_StrongFocus)return false;
-#endif
+		if(w->focusPolicy() == TQWidget::StrongFocus)return false;
 		//TQVariant v = w->property("KviProperty_FocusOwner");
 		//if(v.isValid())return false; // Do NOT change the focus widget!
 		
 		if(w->parent())
 		{
-#ifdef COMPILE_USE_QT4
-			if(w->parent()->metaObject()->indexOfProperty("KviProperty_ChildFocusOwner") == -1)
-#else
 			if(w->parent()->metaObject()->findProperty("KviProperty_ChildFocusOwner") == -1)
-#endif
 				return false; // Do NOT change the focus widget!
 		}
 	}
@@ -429,12 +411,6 @@ void KviWindow::destroyTaskBarItem()
 
 BUTTON_CLASS * KviWindow::createToolButton(TQWidget * par,const char * nam,int pixon,int pixoff,const TQString & tooltip,bool bOn)
 {
-#ifdef COMPILE_USE_QT4
-	BUTTON_CLASS * b = new BUTTON_CLASS(par);
-	b->setObjectName(nam);
-	b->setFlat(true);
-	b->setIcon(TQIcon(*(g_pIconManager->getSmallIcon(pixon))));
-#else
 	BUTTON_CLASS * b = new BUTTON_CLASS(par,nam);
 	b->setToggleButton(true);
 	b->setUsesBigPixmap(false);
@@ -442,7 +418,6 @@ BUTTON_CLASS * KviWindow::createToolButton(TQWidget * par,const char * nam,int p
 	is1.setPixmap(*(g_pIconManager->getSmallIcon(pixon)),TQIconSet::Small,TQIconSet::Normal,TQIconSet::On);
 	is1.setPixmap(*(g_pIconManager->getSmallIcon(pixoff)),TQIconSet::Small,TQIconSet::Normal,TQIconSet::Off);
 	b->setIconSet(is1);
-#endif
 
 
 	KviTalToolTip::add
@@ -456,7 +431,7 @@ void KviWindow::createCryptControllerButton(TQWidget * par)
 {
 #ifdef COMPILE_CRYPT_SUPPORT
 	m_pCryptControllerButton = new KviWindowToolPageButton(KVI_SMALLICON_UNLOCKEDOFF,KVI_SMALLICON_UNLOCKED,__tr2qs("Crypting"),buttonContainer(),false,"crypt_controller_button");
-	connect(m_pCryptControllerButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(toggleCryptController()));
+	connect(m_pCryptControllerButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(toggleCryptController()));
 #endif // COMPILE_CRYPT_SUPPORT
 }
 
@@ -464,7 +439,7 @@ void KviWindow::createTextEncodingButton(TQWidget * par)
 {
 	if(m_pTextEncodingButton)delete m_pTextEncodingButton;
 	m_pTextEncodingButton = createToolButton(par,"text_encoding_button",KVI_SMALLICON_TEXTENCODING,KVI_SMALLICON_TEXTENCODING,__tr2qs("Private Text Encoding"),false);
-	connect(m_pTextEncodingButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(textEncodingButtonClicked()));
+	connect(m_pTextEncodingButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(textEncodingButtonClicked()));
 }
 
 void KviWindow::textEncodingButtonClicked()
@@ -507,8 +482,8 @@ void KviWindow::toggleCryptController()
 		if(m_pSplitter && m_pInput)
 		{
 			m_pCryptController = new KviCryptController(m_pSplitter,m_pCryptControllerButton,"crypt_controller",this,m_pCryptSessionInfo);
-			connect(m_pCryptController,TQT_SIGNAL(done()),this,TQT_SLOT(cryptControllerFinished()));
-			//setFocusHandlerNoClass(m_pInput,m_pCryptController,TQLINEEDIT_OBJECT_NAME_STRING); //link it!
+			connect(m_pCryptController,TQ_SIGNAL(done()),this,TQ_SLOT(cryptControllerFinished()));
+			//setFocusHandlerNoClass(m_pInput,m_pCryptController,"TQLineEdit"); //link it!
 			m_pCryptController->show();
 			if(!m_pCryptControllerButton)
 				return;
@@ -527,7 +502,7 @@ void KviWindow::setCryptSessionInfo(KviCryptSessionInfo * inf)
 	m_pCryptSessionInfo = inf;
 	if(m_pCryptSessionInfo)
 	{
-		connect(m_pCryptSessionInfo->pEngine,TQT_SIGNAL(destroyed()),this,TQT_SLOT(cryptSessionInfoDestroyed()));
+		connect(m_pCryptSessionInfo->pEngine,TQ_SIGNAL(destroyed()),this,TQ_SLOT(cryptSessionInfoDestroyed()));
 	}
 	if(m_pCryptControllerButton)
 	{
@@ -619,11 +594,7 @@ void KviWindow::saveProperties(KviConfig *cfg)
 	TQTextCodec * c = defaultTextCodec();
 	if(c && m_pTextCodec)
 	{
-#ifdef COMPILE_USE_QT4
-		if(KviTQString::equalCI(szCodec,c->name().data()))szCodec = KviTQString::empty; // store "default"
-#else
 		if(KviTQString::equalCI(szCodec,c->name()))szCodec = KviTQString::empty; // store "default"
-#endif
 	}
 	TQString szKey = "TextEncoding_";
 	szKey += m_szName;
@@ -732,7 +703,7 @@ void KviWindow::createSystemTextEncodingPopup()
 	else
 	{
 		g_pMdiWindowSystemTextEncodingPopupStandard->clear();
-		disconnect(g_pMdiWindowSystemTextEncodingPopupStandard,TQT_SIGNAL(activated(int)),0,0);
+		disconnect(g_pMdiWindowSystemTextEncodingPopupStandard,TQ_SIGNAL(activated(int)),0,0);
 	}
 
 	if(!g_pMdiWindowSystemTextEncodingPopupSmart)
@@ -740,7 +711,7 @@ void KviWindow::createSystemTextEncodingPopup()
 	else
 	{
 		g_pMdiWindowSystemTextEncodingPopupSmart->clear();
-		disconnect(g_pMdiWindowSystemTextEncodingPopupSmart,TQT_SIGNAL(activated(int)),0,0);
+		disconnect(g_pMdiWindowSystemTextEncodingPopupSmart,TQ_SIGNAL(activated(int)),0,0);
 	}
 
 	if(!g_pMdiWindowSystemTextEncodingPopupSmartUtf8)
@@ -748,7 +719,7 @@ void KviWindow::createSystemTextEncodingPopup()
 	else
 	{
 		g_pMdiWindowSystemTextEncodingPopupSmartUtf8->clear();
-		disconnect(g_pMdiWindowSystemTextEncodingPopupSmartUtf8,TQT_SIGNAL(activated(int)),0,0);
+		disconnect(g_pMdiWindowSystemTextEncodingPopupSmartUtf8,TQ_SIGNAL(activated(int)),0,0);
 	}
 
 	TQTextCodec * c = defaultTextCodec();
@@ -760,7 +731,7 @@ void KviWindow::createSystemTextEncodingPopup()
 		tmp += ")";
 	}
 
-	int id = g_pMdiWindowSystemTextEncodingPopup->insertItem(tmp,this,TQT_SLOT(systemTextEncodingPopupDefault()));
+	int id = g_pMdiWindowSystemTextEncodingPopup->insertItem(tmp,this,TQ_SLOT(systemTextEncodingPopupDefault()));
 	if(m_szTextEncoding.isEmpty())g_pMdiWindowSystemTextEncodingPopup->setItemChecked(id,true);
 	g_pMdiWindowSystemTextEncodingPopup->insertSeparator();
 
@@ -781,9 +752,9 @@ void KviWindow::createSystemTextEncodingPopup()
 		d = KviLocale::encodingDescription(i);
 	}
 
-	connect(g_pMdiWindowSystemTextEncodingPopupSmart,TQT_SIGNAL(activated(int)),this,TQT_SLOT(systemTextEncodingPopupSmartActivated(int)));
-	connect(g_pMdiWindowSystemTextEncodingPopupSmartUtf8,TQT_SIGNAL(activated(int)),this,TQT_SLOT(systemTextEncodingPopupSmartUtf8Activated(int)));
-	connect(g_pMdiWindowSystemTextEncodingPopupStandard,TQT_SIGNAL(activated(int)),this,TQT_SLOT(systemTextEncodingPopupStandardActivated(int)));
+	connect(g_pMdiWindowSystemTextEncodingPopupSmart,TQ_SIGNAL(activated(int)),this,TQ_SLOT(systemTextEncodingPopupSmartActivated(int)));
+	connect(g_pMdiWindowSystemTextEncodingPopupSmartUtf8,TQ_SIGNAL(activated(int)),this,TQ_SLOT(systemTextEncodingPopupSmartUtf8Activated(int)));
+	connect(g_pMdiWindowSystemTextEncodingPopupStandard,TQ_SIGNAL(activated(int)),this,TQ_SLOT(systemTextEncodingPopupStandardActivated(int)));
 }
 
 
@@ -799,27 +770,27 @@ void KviWindow::systemPopupRequest(const TQPoint &pnt)
 
 	if(mdiParent())
 		g_pMdiWindowSystemMainPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_UNDOCK)),
-		                                        __tr2qs("&Undock"),this,TQT_SLOT(undock()));
+		                                        __tr2qs("&Undock"),this,TQ_SLOT(undock()));
 	else
 		g_pMdiWindowSystemMainPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DOCK)),
-		                                        __tr2qs("&Dock"),this,TQT_SLOT(dock()));
+		                                        __tr2qs("&Dock"),this,TQ_SLOT(dock()));
 
 	g_pMdiWindowSystemMainPopup->insertSeparator();
 
 	int id = g_pMdiWindowSystemMainPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MINIMIZE)),
-		                                        __tr2qs("Mi&nimize"),this,TQT_SLOT(minimize()));
+		                                        __tr2qs("Mi&nimize"),this,TQ_SLOT(minimize()));
 	g_pMdiWindowSystemMainPopup->setItemEnabled(id,!isMinimized());
 	id = g_pMdiWindowSystemMainPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_MAXIMIZE)),
-		                                        __tr2qs("Ma&ximize"),this,TQT_SLOT(maximize()));
+		                                        __tr2qs("Ma&ximize"),this,TQ_SLOT(maximize()));
 	g_pMdiWindowSystemMainPopup->setItemEnabled(id,!isMaximized());
 	id = g_pMdiWindowSystemMainPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_RESTORE)),
-		                                        __tr2qs("&Restore"),this,TQT_SLOT(restore()));
+		                                        __tr2qs("&Restore"),this,TQ_SLOT(restore()));
 	g_pMdiWindowSystemMainPopup->setItemEnabled(id,isMinimized()||isMaximized());
 
 	g_pMdiWindowSystemMainPopup->insertSeparator();
 
 	g_pMdiWindowSystemMainPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CLOSE)),
-	                                        __tr2qs("Close"),this,TQT_SLOT(close()));
+	                                        __tr2qs("Close"),this,TQ_SLOT(close()));
 
 	g_pMdiWindowSystemMainPopup->insertSeparator();
 
@@ -831,7 +802,7 @@ void KviWindow::systemPopupRequest(const TQPoint &pnt)
 
 
 	g_pMdiWindowSystemMainPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_XY)),
-	                                        __tr2qs("Sa&ve Window Properties"),this,TQT_SLOT(savePropertiesAsDefault()));
+	                                        __tr2qs("Sa&ve Window Properties"),this,TQ_SLOT(savePropertiesAsDefault()));
 
 	fillContextPopup(g_pMdiWindowSystemMainPopup);
 
@@ -907,7 +878,7 @@ void KviWindow::dock()
 
 void KviWindow::delayedAutoRaise()
 {
-	TQTimer::singleShot(0,this,TQT_SLOT(autoRaise()));
+	TQTimer::singleShot(0,this,TQ_SLOT(autoRaise()));
 }
 
 void KviWindow::autoRaise()
@@ -925,7 +896,7 @@ void KviWindow::autoRaise()
 
 void KviWindow::delayedClose()
 {
-	TQTimer::singleShot(0,this,TQT_SLOT(close()));
+	TQTimer::singleShot(0,this,TQ_SLOT(close()));
 }
 
 void KviWindow::closeEvent(TQCloseEvent *e)
@@ -953,7 +924,7 @@ void KviWindow::youAreDocked()
 	}
 	((KviMdiChild *)parent())->setIcon(*myIconPtr());
 	updateCaption();
-	connect(((KviMdiChild *)parent()),TQT_SIGNAL(systemPopupRequest(const TQPoint &)),this,TQT_SLOT(systemPopupRequest(const TQPoint &)));
+	connect(((KviMdiChild *)parent()),TQ_SIGNAL(systemPopupRequest(const TQPoint &)),this,TQ_SLOT(systemPopupRequest(const TQPoint &)));
 }
 
 void KviWindow::youAreUndocked()
@@ -1005,18 +976,6 @@ void KviWindow::focusInEvent(TQFocusEvent *)
 		
 		if(m_pIrcView)m_pFocusHandler = m_pIrcView;
 		else {
-#ifdef COMPILE_USE_QT4
-			TQPtrList<TQObject *> list = children();
-			for(TQPtrList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
-			{
-				TQObject * c = *it;
-				if(c->isWidgetType())
-				{
-					m_pFocusHandler = (TQWidget *)c;
-					break;
-				}
-			}
-#else
 			TQObjectList list = childrenListObject();
 			if(!list.isEmpty())
 			{
@@ -1029,7 +988,6 @@ void KviWindow::focusInEvent(TQFocusEvent *)
 					}
 				}
 			}
-#endif
 		}
 		if(m_pFocusHandler)m_pFocusHandler->setFocus();
 		else {
@@ -1065,13 +1023,8 @@ bool KviWindow::eventFilter(TQObject *o,TQEvent *e)
 			TQApplication::restoreOverrideCursor();
 		break;
 	case TQEvent::MouseButtonPress:
-#ifdef COMPILE_USE_QT4
-		if( (((TQWidget *)o)->focusPolicy() == TQ_NoFocus) ||
-		        (((TQWidget *)o)->focusPolicy() == TQ_TabFocus))
-#else
-		if( (((TQWidget *)o)->focusPolicy() == TQ_NoFocus) ||
-		        (((TQWidget *)o)->focusPolicy() == TQ_TabFocus))
-#endif
+		if( (((TQWidget *)o)->focusPolicy() == TQWidget::NoFocus) ||
+		        (((TQWidget *)o)->focusPolicy() == TQWidget::TabFocus))
 		{
 			// this will not focus our window
 			// set the focus to the focus handler
@@ -1107,33 +1060,18 @@ void KviWindow::childInserted(TQWidget * o)
 {
 	o->removeEventFilter(this); // ensure that we don't filter twice
 	o->installEventFilter(this); // we filter its events
-	connect(o,TQT_SIGNAL(destroyed()),this,TQT_SLOT(childDestroyed()));
+	connect(o,TQ_SIGNAL(destroyed()),this,TQ_SLOT(childDestroyed()));
 
 	if(o->inherits("KviInput"))
 		m_pFocusHandler = o;
 	else
 	{
-#ifdef COMPILE_USE_QT4
-		if(!m_pFocusHandler && (o->focusPolicy() == TQ_StrongFocus))
-#else
-		if(!m_pFocusHandler && (o->focusPolicy() == TQ_StrongFocus))
-#endif
+		if(!m_pFocusHandler && (o->focusPolicy() == TQWidget::StrongFocus))
 		{
 			m_pFocusHandler = o;
 		}
 	}
 
-#ifdef COMPILE_USE_QT4
-	TQPtrList<TQObject *> list = o->children();
-	for(TQPtrList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
-	{
-		TQObject * c = *it;
-		if(c->isWidgetType())
-		{
-			childInserted((TQWidget *)c);
-		}
-	}
-#else
 	TQObjectList list = o->childrenListObject();
 	if(!list.isEmpty())
 	{
@@ -1143,7 +1081,6 @@ void KviWindow::childInserted(TQWidget * o)
 				childInserted((TQWidget *)c);
 		}
 	}
-#endif
 }
 
 void KviWindow::childDestroyed()
@@ -1161,17 +1098,6 @@ void KviWindow::childRemoved(TQWidget * o)
 	if(o == m_pLastFocusedChild)
 		m_pLastFocusedChild = 0;
 
-#ifdef COMPILE_USE_QT4
-	TQPtrList<TQObject *> list = o->children();
-	for(TQPtrList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
-	{
-		TQObject * c = *it;
-		if(c->isWidgetType())
-		{
-			childRemoved((TQWidget *)c);
-		}
-	}
-#else
 	TQObjectList list = o->childrenListObject();
 	if(!list.isEmpty())
 	{
@@ -1181,7 +1107,6 @@ void KviWindow::childRemoved(TQWidget * o)
 				childRemoved((TQWidget *)c);
 		}
 	} //else tqDebug("The removed object has no children");
-#endif
 }
 
 void KviWindow::childEvent(TQChildEvent *e)
@@ -1215,37 +1140,19 @@ void KviWindow::childrenTreeChanged(TQWidget * widgetAdded)
 void KviWindow::updateBackgrounds(TQObject * obj)
 {
 	if(!obj)
-		obj = TQT_TQOBJECT(this);
-#ifdef COMPILE_USE_QT4
-	TQPtrList<TQObject *> list = obj->children();
-	if (list.count())
-	{
-	
-	for(TQPtrList<TQObject *>::Iterator it = list.begin();it != list.end();++it)
-	{
-		TQObject * child = *it;
-		if(child->metaObject()->indexOfProperty("TransparencyCapable") != -1){
-		//	if (child->isWidgetType())
-			((TQWidget *)child)->update();
-		}
-		updateBackgrounds(child);
-	}
-	}
-#else
+		obj = this;
 	TQObjectList list = obj->childrenListObject();
 	if(!list.isEmpty())
 	{
 		for(unsigned int i=0;i<list.count();i++)
 		{
 			TQObject * child = list.at(i);
-			// FIXME: check if this code can work with qt < 3.0.0 too
 			if(child->metaObject()->findProperty("TransparencyCapable",true) != -1)
 				((TQWidget *)child)->update();
 
 			updateBackgrounds(child);
 		}
 	}
-#endif
 }
 
 void KviWindow::moveEvent(TQMoveEvent *e)
@@ -1476,11 +1383,7 @@ void KviWindow::unhighlight()
 void KviWindow::preprocessMessage(TQString & szMessage)
 {
 	// slow
-#ifdef COMPILE_USE_QT4
-	TQStringList strings = szMessage.split(" ");
-#else
 	TQStringList strings = TQStringList::split(" ",szMessage, TRUE);
-#endif
 	for ( TQStringList::Iterator it = strings.begin(); it != strings.end(); ++it ) {
 		TQString tmp(*it);
 		if(tmp.contains('\r')) continue;
