@@ -1058,7 +1058,7 @@ void KviCanvasView::contentsMouseMoveEvent(TQMouseEvent *e)
 {
 //	TQPoint p = inverseWorldMatrix().map(e->pos());
 	TQPoint p = e->pos();
-	if(e->state() & Qt::LeftButton)
+	if(e->state() & TQt::LeftButton)
 	{
 		if((m_dragMode != None) && (m_pSelectedItem))
 		{
@@ -1128,7 +1128,7 @@ void KviCanvasView::contentsMouseReleaseEvent(TQMouseEvent *e)
 
 void KviCanvasView::contentsMousePressEvent(TQMouseEvent *e)
 {
-	if(e->button() & Qt::LeftButton)
+	if(e->button() & TQt::LeftButton)
 	{
 //	    TQPoint p = inverseWorldMatrix().map(e->pos());
 		TQPoint p = e->pos();
@@ -1240,7 +1240,7 @@ TQWidget * KviVariantTableItem::createEditor() const
 			TQString sz;
 			sz.setNum(m_property.toInt());
 			e->setText(sz);
-			e->setValidator(new TQIntValidator(TQT_TQOBJECT(e)));
+			e->setValidator(new TQIntValidator(e));
 			return e;
 		}
 		break;
@@ -1250,7 +1250,7 @@ TQWidget * KviVariantTableItem::createEditor() const
 			TQString sz;
 			sz.setNum(m_property.toInt());
 			e->setText(sz);
-			TQIntValidator * i = new TQIntValidator(TQT_TQOBJECT(e));
+			TQIntValidator * i = new TQIntValidator(e);
 			i->setBottom(0);
 			e->setValidator(i);
 			return e;
@@ -1409,7 +1409,7 @@ KviCanvasItemPropertiesWidget::KviCanvasItemPropertiesWidget(TQWidget * par)
 	setSorting(false);
 	setLeftMargin(0);
 	verticalHeader()->hide();
-	connect(this,TQT_SIGNAL(valueChanged(int,int)),this,TQT_SLOT(cellEdited(int,int)));
+	connect(this,TQ_SIGNAL(valueChanged(int,int)),this,TQ_SLOT(cellEdited(int,int)));
 }
 
 KviCanvasItemPropertiesWidget::~KviCanvasItemPropertiesWidget()
@@ -1493,11 +1493,11 @@ void KviCanvasItemPropertiesWidget::editItem(TQCanvasItem * it)
 KviCanvasWidget::KviCanvasWidget(TQWidget * par)
 : TQWidget(par,"canvas_widget")
 {
-	m_pCanvas = new TQCanvas(TQT_TQOBJECT(this));
+	m_pCanvas = new TQCanvas(this);
 //#warning "Make this size as parameter of Dcc ?"
 	m_pCanvas->resize(648,480);
 	m_pMenuBar = new TQMenuBar(this);
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this);
+	m_pSplitter = new TQSplitter(TQt::Horizontal,this);
 	m_pCanvasView = new KviCanvasView(m_pCanvas,this,m_pSplitter);
 	m_pStatusLabel = new TQLabel(this);
 	m_pPropertiesWidget = new KviCanvasItemPropertiesWidget(m_pSplitter);
@@ -1506,24 +1506,24 @@ KviCanvasWidget::KviCanvasWidget(TQWidget * par)
 	l.append(20);
 	m_pSplitter->setSizes(l);
 
-	connect(m_pPropertiesWidget,TQT_SIGNAL(propertyChanged(const TQString &,const TQVariant &)),m_pCanvasView,TQT_SLOT(propertyChanged(const TQString &,const TQVariant &)));
+	connect(m_pPropertiesWidget,TQ_SIGNAL(propertyChanged(const TQString &,const TQVariant &)),m_pCanvasView,TQ_SLOT(propertyChanged(const TQString &,const TQVariant &)));
 
 	KviTalPopupMenu * add = new KviTalPopupMenu(m_pMenuBar);
 	KviTalPopupMenu * shapes = new KviTalPopupMenu(add);
 	KviTalPopupMenu * polygons = new KviTalPopupMenu(add);
 	KviTalPopupMenu * items = new KviTalPopupMenu(add);
-	shapes->insertItem(__tr2qs_ctx("&Line","dcc"),m_pCanvasView,TQT_SLOT(insertLine()));
-	shapes->insertItem(__tr2qs_ctx("&Rectangle","dcc"),m_pCanvasView,TQT_SLOT(insertRectangle()));
-	shapes->insertItem(__tr2qs_ctx("&Ellipse","dcc"),m_pCanvasView,TQT_SLOT(insertEllipse()));
-	shapes->insertItem(__tr2qs_ctx("&Pie","dcc"),m_pCanvasView,TQT_SLOT(insertPie()));
-	shapes->insertItem(__tr2qs_ctx("&Chord","dcc"),m_pCanvasView,TQT_SLOT(insertChord()));
+	shapes->insertItem(__tr2qs_ctx("&Line","dcc"),m_pCanvasView,TQ_SLOT(insertLine()));
+	shapes->insertItem(__tr2qs_ctx("&Rectangle","dcc"),m_pCanvasView,TQ_SLOT(insertRectangle()));
+	shapes->insertItem(__tr2qs_ctx("&Ellipse","dcc"),m_pCanvasView,TQ_SLOT(insertEllipse()));
+	shapes->insertItem(__tr2qs_ctx("&Pie","dcc"),m_pCanvasView,TQ_SLOT(insertPie()));
+	shapes->insertItem(__tr2qs_ctx("&Chord","dcc"),m_pCanvasView,TQ_SLOT(insertChord()));
 
-	items->insertItem(__tr2qs_ctx("&Rich text (html)","dcc"),m_pCanvasView,TQT_SLOT(insertRichText()));
+	items->insertItem(__tr2qs_ctx("&Rich text (html)","dcc"),m_pCanvasView,TQ_SLOT(insertRichText()));
 
-	polygons->insertItem(__tr2qs_ctx("&Triangle","dcc"),m_pCanvasView,TQT_SLOT(insertPolygonTriangle()));
-	polygons->insertItem(__tr2qs_ctx("&Rectangle","dcc"),m_pCanvasView,TQT_SLOT(insertPolygonRectangle()));
-	polygons->insertItem(__tr2qs_ctx("&Pentagon","dcc"),m_pCanvasView,TQT_SLOT(insertPolygonPentagon()));
-	polygons->insertItem(__tr2qs_ctx("&Hexagon","dcc"),m_pCanvasView,TQT_SLOT(insertPolygonHexagon()));
+	polygons->insertItem(__tr2qs_ctx("&Triangle","dcc"),m_pCanvasView,TQ_SLOT(insertPolygonTriangle()));
+	polygons->insertItem(__tr2qs_ctx("&Rectangle","dcc"),m_pCanvasView,TQ_SLOT(insertPolygonRectangle()));
+	polygons->insertItem(__tr2qs_ctx("&Pentagon","dcc"),m_pCanvasView,TQ_SLOT(insertPolygonPentagon()));
+	polygons->insertItem(__tr2qs_ctx("&Hexagon","dcc"),m_pCanvasView,TQ_SLOT(insertPolygonHexagon()));
 
 	add->insertItem(__tr2qs_ctx("&Shape","dcc"),shapes);
 	add->insertItem(__tr2qs_ctx("&Item","dcc"),items);
