@@ -32,11 +32,7 @@
 #include "kvi_tal_scrollview.h"
 #include <tqmessagebox.h>
 #include <tqtimer.h>
-#ifdef COMPILE_USE_QT4
-	//#define TQSyntaxHighlighter Q3SyntaxHighlighter
-#else
 	#include <tqobjectlist.h>
-#endif
 #include <tqcursor.h>
 #include <tqfont.h>
 #include <tqrect.h>
@@ -79,11 +75,7 @@ KviCompletionBox::KviCompletionBox(TQWidget * parent)
 {
 	setPaletteForegroundColor(TQColor(0,0,0));
 	setPaletteBackgroundColor(TQColor(255,255,255));
-#ifdef COMPILE_USE_QT4
-	setHScrollBarMode(KviTalListBox::AlwaysOff);
-#else
 	setHScrollBarMode(TQScrollView::AlwaysOff);
-#endif
 	TQFont listfont=font();
 	listfont.setPointSize(8);
 	setFont(listfont);
@@ -175,7 +167,7 @@ KviScriptEditorWidgetColorOptions::KviScriptEditorWidgetColorOptions(TQWidget *
 	KviFontSelector * f = new KviFontSelector(this,__tr2qs_ctx("Font:","editor"),&g_fntNormal,true);
 	g->addMultiCellWidget(f,0,0,0,2);
 	m_pSelectorInterfaceList->append(f);
-	KviTalGroupBox * gbox = new KviTalGroupBox(1,Qt::Horizontal,__tr2qs("Colors" ),this);
+	KviTalGroupBox * gbox = new KviTalGroupBox(1,TQt::Horizontal,__tr2qs("Colors" ),this);
 	g->addMultiCellWidget(gbox,1,1,0,2);
 	KviColorSelector * s = addColorSelector(gbox,__tr2qs_ctx("Background:","editor"),&g_clrBackground,true);
 	s = addColorSelector(gbox,__tr2qs_ctx("Normal text:","editor"),&g_clrNormalText,true);
@@ -189,11 +181,11 @@ KviScriptEditorWidgetColorOptions::KviScriptEditorWidgetColorOptions(TQWidget *
 	
 	TQPushButton * b = new TQPushButton(__tr2qs_ctx("&OK","editor"),this);
 	b->setDefault(true);
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(okClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(okClicked()));
 	g->addWidget(b,2,1);
 
 	b = new TQPushButton(__tr2qs_ctx("Cancel","editor"),this);
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(reject()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(reject()));
 	g->addWidget(b,2,2);
 
 
@@ -233,7 +225,7 @@ KviScriptEditorWidget::KviScriptEditorWidget(TQWidget * pParent)
 	updateOptions();
 	m_szFind="";
 	completelistbox=new KviCompletionBox(this);
-	connect (completelistbox,TQT_SIGNAL(selected(const TQString &)),this,TQT_SLOT(slotComplete(const TQString &)));
+	connect (completelistbox,TQ_SIGNAL(selected(const TQString &)),this,TQ_SLOT(slotComplete(const TQString &)));
 }
 
 KviScriptEditorWidget::~KviScriptEditorWidget()
@@ -241,19 +233,11 @@ KviScriptEditorWidget::~KviScriptEditorWidget()
 
 }
 
-#ifdef COMPILE_USE_QT4
-Q3PopupMenu * KviScriptEditorWidget::createPopupMenu( const TQPoint& pos )
-#else
 TQPopupMenu * KviScriptEditorWidget::createPopupMenu( const TQPoint& pos )
-#endif
 {
-#ifdef COMPILE_USE_QT4
-	Q3PopupMenu *pop=KviTalTextEdit::createPopupMenu(pos);
-#else
 	TQPopupMenu *pop=KviTalTextEdit::createPopupMenu(pos);
-#endif
-	pop->insertItem(__tr2qs("Context sensitive help"),this,TQT_SLOT(slotHelp()),TQt::CTRL+TQt::Key_H);
-	pop->insertItem(__tr2qs("&Replace"),this,TQT_SLOT(slotReplace()),TQt::CTRL+TQt::Key_R);
+	pop->insertItem(__tr2qs("Context sensitive help"),this,TQ_SLOT(slotHelp()),TQt::CTRL+TQt::Key_H);
+	pop->insertItem(__tr2qs("&Replace"),this,TQ_SLOT(slotReplace()),TQt::CTRL+TQt::Key_R);
 	return pop;
 }
 
@@ -265,10 +249,10 @@ void KviScriptEditorWidget::slotFind()
 
 void KviScriptEditorWidget::slotReplace()
 {
-	KviScriptEditorReplaceDialog *dialog=new KviScriptEditorReplaceDialog(this,tqtr("Find & Repalce"));
-	connect (dialog,TQT_SIGNAL(replaceAll(const TQString &,const TQString &)),m_pParent,TQT_SLOT(slotReplaceAll(const TQString &,const TQString &)));
-	connect (dialog,TQT_SIGNAL(initFind()),m_pParent,TQT_SLOT(slotInitFind()));
-	connect (dialog,TQT_SIGNAL(nextFind(const TQString &)),m_pParent,TQT_SLOT(slotNextFind(const TQString &)));
+	KviScriptEditorReplaceDialog *dialog=new KviScriptEditorReplaceDialog(this,tr("Find & Replace"));
+	connect (dialog,TQ_SIGNAL(replaceAll(const TQString &,const TQString &)),m_pParent,TQ_SLOT(slotReplaceAll(const TQString &,const TQString &)));
+	connect (dialog,TQ_SIGNAL(initFind()),m_pParent,TQ_SLOT(slotInitFind()));
+	connect (dialog,TQ_SIGNAL(nextFind(const TQString &)),m_pParent,TQ_SLOT(slotNextFind(const TQString &)));
 	if(dialog->exec()){};
 
 }
@@ -288,11 +272,7 @@ void KviScriptEditorWidget::updateOptions()
 	p.setColor(TQColorGroup::Text,g_clrNormalText);
 	setPalette(p);
 	
-#ifdef COMPILE_USE_QT4
-	setTextFormat(TQt::PlainText);
-#else
 	setTextFormat(KviTalTextEdit::PlainText);
-#endif
 	
 	// this will rehighlight everything
 	setText(text()); // an "hack" to ensure Update all in the editor
@@ -400,7 +380,7 @@ void KviScriptEditorWidget::keyPressEvent(TQKeyEvent * e)
 void KviScriptEditorWidget::contentsMousePressEvent(TQMouseEvent *e)
 {
 	completelistbox->hide();
-	if (e->button() == Qt::RightButton)
+	if (e->button() == TQt::RightButton)
 	{
 //	bool bIsFirstWordInLine;
 	TQString buffer;
@@ -847,9 +827,7 @@ KviScriptEditorImplementation::KviScriptEditorImplementation(TQWidget * par)
 	TQGridLayout * g = new TQGridLayout(this,2,3,0,0);
 
 	m_pFindLineedit = new TQLineEdit(" ",this);
-#ifndef COMPILE_USE_QT4
 	m_pFindLineedit->setFrameStyle(TQFrame::Sunken | TQFrame::Panel);
-#endif
 	m_pFindLineedit->setText("");
 	m_pFindLineedit->setPaletteForegroundColor(g_clrFind);
 
@@ -857,19 +835,15 @@ KviScriptEditorImplementation::KviScriptEditorImplementation(TQWidget * par)
 	g->addMultiCellWidget(m_pEditor,0,0,0,3);
 	g->setRowStretch(0,1);
 
-#ifdef COMPILE_USE_QT4
-	TQToolButton * b = new TQToolButton(TQt::DownArrow,this,"dsa2");
-#else
 	TQToolButton * b = new TQToolButton(DownArrow,this);
-#endif
 	b->setMinimumWidth(24);
 	g->addWidget(b,1,0);
 
 	KviTalPopupMenu * pop = new KviTalPopupMenu(b);
-	pop->insertItem(__tr2qs_ctx("&Open...","editor"),this,TQT_SLOT(loadFromFile()));
-	pop->insertItem(__tr2qs_ctx("&Save As...","editor"),this,TQT_SLOT(saveToFile()));
+	pop->insertItem(__tr2qs_ctx("&Open...","editor"),this,TQ_SLOT(loadFromFile()));
+	pop->insertItem(__tr2qs_ctx("&Save As...","editor"),this,TQ_SLOT(saveToFile()));
 	pop->insertSeparator();
-	pop->insertItem(__tr2qs_ctx("&Configure Editor...","editor"),this,TQT_SLOT(configureColors()));
+	pop->insertItem(__tr2qs_ctx("&Configure Editor...","editor"),this,TQ_SLOT(configureColors()));
 	b->setPopup(pop);
 	b->setPopupDelay(1);
 
@@ -885,11 +859,11 @@ KviScriptEditorImplementation::KviScriptEditorImplementation(TQWidget * par)
 	m_pRowColLabel->setMinimumWidth(80);
 	g->addWidget(m_pRowColLabel,1,3);
 
-	connect(m_pFindLineedit,TQT_SIGNAL(returnPressed()),m_pEditor,TQT_SLOT(slotFind()));
-	connect(m_pFindLineedit,TQT_SIGNAL(returnPressed()),this,TQT_SLOT(slotFind()));
-	connect(m_pEditor,TQT_SIGNAL(keyPressed()),this,TQT_SLOT(updateRowColLabel()));
-	connect(m_pEditor,TQT_SIGNAL(textChanged()),this,TQT_SLOT(updateRowColLabel()));
-	connect(m_pEditor,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(updateRowColLabel()));
+	connect(m_pFindLineedit,TQ_SIGNAL(returnPressed()),m_pEditor,TQ_SLOT(slotFind()));
+	connect(m_pFindLineedit,TQ_SIGNAL(returnPressed()),this,TQ_SLOT(slotFind()));
+	connect(m_pEditor,TQ_SIGNAL(keyPressed()),this,TQ_SLOT(updateRowColLabel()));
+	connect(m_pEditor,TQ_SIGNAL(textChanged()),this,TQ_SLOT(updateRowColLabel()));
+	connect(m_pEditor,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(updateRowColLabel()));
 	m_lastCursorPos = TQPoint(-1,-1);
 }
 
@@ -1006,11 +980,7 @@ void KviScriptEditorImplementation::saveToFile()
 void KviScriptEditorImplementation::setText(const KviTQCString &txt)
 {
 	m_pEditor->setText(txt.data());
-#ifdef COMPILE_USE_QT4
-	m_pEditor->setTextFormat(TQt::PlainText);
-#else
 	m_pEditor->setTextFormat(KviTalTextEdit::PlainText);
-#endif
 	m_pEditor->moveCursor(KviTalTextEdit::MoveEnd,false);
 	m_pEditor->setModified(false);
 	updateRowColLabel();
@@ -1027,11 +997,7 @@ TQLineEdit * KviScriptEditorImplementation::getFindlineedit()
 void KviScriptEditorImplementation::setText(const TQString &txt)
 {
 	m_pEditor->setText(txt);
-#ifdef COMPILE_USE_QT4
-	m_pEditor->setTextFormat(TQt::PlainText);
-#else
 	m_pEditor->setTextFormat(KviTalTextEdit::PlainText);
-#endif
 	m_pEditor->moveCursor(KviTalTextEdit::MoveEnd,false);
 	m_pEditor->setModified(false);
 	updateRowColLabel();
@@ -1127,36 +1093,28 @@ KviScriptEditorReplaceDialog::KviScriptEditorReplaceDialog( TQWidget* parent, co
 	TQGridLayout *layout = new TQGridLayout( this, 1, 1, 11, 6, "replace layout"); 
  
 	m_pFindlineedit = new TQLineEdit( this, "findlineedit" );
-#ifndef COMPILE_USE_QT4
 	m_pFindlineedit->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)0, 0, 0, m_pFindlineedit->sizePolicy().hasHeightForWidth() ) );
 	m_pFindlineedit->setFrameShape( TQLineEdit::LineEditPanel );
 	m_pFindlineedit->setFrameShadow( TQLineEdit::Sunken );
-#endif
 
 	layout->addMultiCellWidget( m_pFindlineedit, 2, 2, 1, 2 );
 
 	m_pReplacelineedit = new TQLineEdit( this, "replacelineedit" );
-#ifndef COMPILE_USE_QT4
 	m_pReplacelineedit->setFrameShape( TQLineEdit::LineEditPanel );
 	m_pReplacelineedit->setFrameShadow( TQLineEdit::Sunken );
-#endif
 	layout->addMultiCellWidget( m_pReplacelineedit, 3, 3, 1, 2 );
 
    	m_pFindlineedit->setFocus();
 
     TQLabel *findlabel = new TQLabel( this, "findlabel" );
 	findlabel->setText(tr("Word to Find"));
-#ifndef COMPILE_USE_QT4
 	findlabel->setAutoResize(true);
-#endif
 
 	layout->addWidget( findlabel, 2, 0 );
 
     TQLabel *replacelabel = new TQLabel( this, "replacelabel" );
 	replacelabel->setText(tr("Replace with"));
-#ifndef COMPILE_USE_QT4
 	replacelabel->setAutoResize(true);
-#endif
 	layout->addWidget( replacelabel, 3, 0 );
 
     TQPushButton *cancelbutton = new TQPushButton( this, "cancelButton" );
@@ -1182,15 +1140,13 @@ KviScriptEditorReplaceDialog::KviScriptEditorReplaceDialog( TQWidget* parent, co
 	layout->addWidget( replace, 3, 3 );
 	replace->setEnabled(false);
 
-#ifndef COMPILE_USE_QT4
     clearWState( WState_Polished );
 	setTabOrder(m_pFindlineedit,m_pReplacelineedit);
-#endif
 	// signals and slots connections
-	connect( replacebutton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotReplace() ) );
-	connect( findNext, TQT_SIGNAL( clicked() ),this,TQT_SLOT( slotNextFind()));
-	connect( cancelbutton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( reject() ) );
-	connect( m_pFindlineedit, TQT_SIGNAL( textChanged(const TQString &)), this, TQT_SLOT( textChanged(const TQString &)));
+	connect( replacebutton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotReplace() ) );
+	connect( findNext, TQ_SIGNAL( clicked() ),this,TQ_SLOT( slotNextFind()));
+	connect( cancelbutton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( reject() ) );
+	connect( m_pFindlineedit, TQ_SIGNAL( textChanged(const TQString &)), this, TQ_SLOT( textChanged(const TQString &)));
 
 }
 
