@@ -629,11 +629,7 @@ static bool file_kvs_fnc_ls(KviKvsModuleFunctionCall * c)
 		return true;
 	}
 
-#ifdef COMPILE_USE_QT4
-	TQFlags<TQDir::Filter> iFlags = 0;
-#else
 	int iFlags = 0;
-#endif
 	if(szFlags.isEmpty())iFlags = TQDir::Dirs | TQDir::Files | TQDir::NoSymLinks | TQDir::Readable | TQDir::Writable | TQDir::Executable | TQDir::Hidden | TQDir::System;
 	else {
 		if(szFlags.find('d',false) != -1)iFlags |= TQDir::Dirs;
@@ -645,11 +641,7 @@ static bool file_kvs_fnc_ls(KviKvsModuleFunctionCall * c)
 		if(szFlags.find('h',false) != -1)iFlags |= TQDir::Hidden;
 		if(szFlags.find('s',false) != -1)iFlags |= TQDir::System;
 	}
-#ifdef COMPILE_USE_QT4
-	TQFlags<TQDir::SortFlag> iSort = 0;
-#else
 	int iSort = 0;
-#endif
 	if(szFlags.isEmpty())iSort = TQDir::Unsorted;
 	else {
 		if(szFlags.find('n',false) != -1)iSort |= TQDir::Name;
