@@ -39,11 +39,7 @@
 #include <tqsplitter.h>
 #include <tqtooltip.h>
 #include "kvi_tal_hbox.h"
-#ifdef COMPILE_USE_QT4
-	#include <tq3header.h>
-#else
 	#include <tqheader.h>
-#endif
 #include <tqpainter.h>
 #include <tqmessagebox.h>
 #include <tqclipboard.h>
@@ -151,12 +147,12 @@ KviFileTransferWindow::KviFileTransferWindow(KviModuleExtensionDescriptor * d,Kv
 	m_pMemPixmap = new TQPixmap(1,1);
 
 	m_pTimer = new TQTimer(this);
-	connect(m_pTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(heartbeat()));
+	connect(m_pTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(heartbeat()));
 
 	m_pInput   = new KviInput(this,0);
 
-	m_pSplitter = new TQSplitter(Qt::Horizontal,this,"splitter");
-	m_pVertSplitter = new TQSplitter(Qt::Vertical,m_pSplitter,"vsplitter");
+	m_pSplitter = new TQSplitter(TQt::Horizontal,this,"splitter");
+	m_pVertSplitter = new TQSplitter(TQt::Vertical,m_pSplitter,"vsplitter");
 
 	m_pListView  = new KviTalListView(m_pVertSplitter);
 	//m_pListView->header()->hide();
@@ -166,13 +162,13 @@ KviFileTransferWindow::KviFileTransferWindow(KviModuleExtensionDescriptor * d,Kv
 	m_pListView->addColumn(__tr2qs_ctx("Progress","filetransferwindow"),350);
 
 	KviDynamicToolTip * tp = new KviDynamicToolTip(m_pListView->viewport());
-	connect(tp,TQT_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQT_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
+	connect(tp,TQ_SIGNAL(tipRequest(KviDynamicToolTip *,const TQPoint &)),this,TQ_SLOT(tipRequest(KviDynamicToolTip *,const TQPoint &)));
 
 	//m_pListView->setFocusPolicy(NoFocus);
 	//m_pListView->viewport()->setFocusPolicy(NoFocus);
 
-	//connect(m_pListView,TQT_SIGNAL(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)),
-	// this,TQT_SLOT(showHostPopup(KviTalListViewItem *,const TQPoint &,int)));
+	//connect(m_pListView,TQ_SIGNAL(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)),
+	// this,TQ_SLOT(showHostPopup(KviTalListViewItem *,const TQPoint &,int)));
 
 	TQFontMetrics fm(font());
 	m_iLineSpacing = fm.lineSpacing();
@@ -180,12 +176,12 @@ KviFileTransferWindow::KviFileTransferWindow(KviModuleExtensionDescriptor * d,Kv
 	m_pIrcView = new KviIrcView(m_pVertSplitter,lpFrm,this);
 
 	m_pListView->installEventFilter(this);
-	connect(m_pListView,TQT_SIGNAL(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)),this,TQT_SLOT(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)));
-	connect(m_pListView,TQT_SIGNAL(doubleClicked(KviTalListViewItem *,const TQPoint &,int)),this,TQT_SLOT(doubleClicked(KviTalListViewItem *,const TQPoint &,int)));
+	connect(m_pListView,TQ_SIGNAL(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)),this,TQ_SLOT(rightButtonPressed(KviTalListViewItem *,const TQPoint &,int)));
+	connect(m_pListView,TQ_SIGNAL(doubleClicked(KviTalListViewItem *,const TQPoint &,int)),this,TQ_SLOT(doubleClicked(KviTalListViewItem *,const TQPoint &,int)));
 	fillTransferView();
 
-	connect(KviFileTransferManager::instance(),TQT_SIGNAL(transferRegistered(KviFileTransfer *)),this,TQT_SLOT(transferRegistered(KviFileTransfer *)));
-	connect(KviFileTransferManager::instance(),TQT_SIGNAL(transferUnregistering(KviFileTransfer *)),this,TQT_SLOT(transferUnregistering(KviFileTransfer *)));
+	connect(KviFileTransferManager::instance(),TQ_SIGNAL(transferRegistered(KviFileTransfer *)),this,TQ_SLOT(transferRegistered(KviFileTransfer *)));
+	connect(KviFileTransferManager::instance(),TQ_SIGNAL(transferUnregistering(KviFileTransfer *)),this,TQ_SLOT(transferUnregistering(KviFileTransfer *)));
 
 	KviFileTransferManager::instance()->setTransferWindow(this);
 
@@ -203,7 +199,7 @@ KviFileTransferWindow::~KviFileTransferWindow()
 
 bool KviFileTransferWindow::eventFilter( TQObject *obj, TQEvent *ev )
 {
-	if( (TQT_BASE_OBJECT(obj)==TQT_BASE_OBJECT(m_pListView)) && ( ev->type() == TQEvent::KeyPress ) )
+	if( (obj==m_pListView) && ( ev->type() == TQEvent::KeyPress ) )
 	{
 		TQKeyEvent *keyEvent = (TQKeyEvent*)ev;
 		switch(keyEvent->key())
@@ -286,7 +282,7 @@ void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const TQPo
 	if(!m_pOpenFilePopup)
 	{
 		m_pOpenFilePopup= new KviTalPopupMenu(this);
-		connect(m_pOpenFilePopup,TQT_SIGNAL(activated(int)),this,TQT_SLOT(openFilePopupActivated(int)));
+		connect(m_pOpenFilePopup,TQ_SIGNAL(activated(int)),this,TQ_SLOT(openFilePopupActivated(int)));
 	}
 
 	m_pContextPopup->clear();
@@ -331,7 +327,7 @@ void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const TQPo
 				TQString mimetype = KMimeType::findByPath(szFile)->name();
 				KServiceTypeProfile::OfferList offers = KServiceTypeProfile::offers(mimetype,"Application");
 
-				id = m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Open","filetransferwindow"),this,TQT_SLOT(openLocalFile()));
+				id = m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Open","filetransferwindow"),this,TQ_SLOT(openLocalFile()));
 				m_pLocalFilePopup->setItemParameter(id,-1);
 
 				m_pOpenFilePopup->clear();
@@ -349,32 +345,32 @@ void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const TQPo
 
 				m_pOpenFilePopup->insertSeparator();
 
-				id = m_pOpenFilePopup->insertItem(__tr2qs_ctx("&Other...","filetransferwindow"),this,TQT_SLOT(openLocalFileWith()));
+				id = m_pOpenFilePopup->insertItem(__tr2qs_ctx("&Other...","filetransferwindow"),this,TQ_SLOT(openLocalFileWith()));
 				m_pOpenFilePopup->setItemParameter(id,-1);
 
 				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &With","filetransferwindow"),m_pOpenFilePopup);
 				m_pLocalFilePopup->insertSeparator();
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &Location","filetransferwindow"),this,TQT_SLOT(openLocalFileFolder()));
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Terminal at Location","filetransferwindow"),this,TQT_SLOT(openLocalFileTerminal()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &Location","filetransferwindow"),this,TQ_SLOT(openLocalFileFolder()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Terminal at Location","filetransferwindow"),this,TQ_SLOT(openLocalFileTerminal()));
 				m_pLocalFilePopup->insertSeparator();
 #endif //COMPILE_TDE_SUPPORT
 
 //-| Grifisx & Noldor |-
 #ifdef COMPILE_ON_WINDOWS
-				id = m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Open","filetransferwindow"),this,TQT_SLOT(openLocalFile()));
+				id = m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Open","filetransferwindow"),this,TQ_SLOT(openLocalFile()));
 				m_pLocalFilePopup->setItemParameter(id,-1);
 				m_pOpenFilePopup->insertSeparator();
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &With","filetransferwindow"),this,TQT_SLOT(openLocalFileWith()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &With","filetransferwindow"),this,TQ_SLOT(openLocalFileWith()));
 				m_pLocalFilePopup->insertSeparator();
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &Location","filetransferwindow"),this,TQT_SLOT(openLocalFileFolder()));
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("MS-DOS Prompt at Location","filetransferwindow"),this,TQT_SLOT(openLocalFileTerminal()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("Open &Location","filetransferwindow"),this,TQ_SLOT(openLocalFileFolder()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("MS-DOS Prompt at Location","filetransferwindow"),this,TQ_SLOT(openLocalFileTerminal()));
 				m_pLocalFilePopup->insertSeparator();
 #endif //COMPILE_ON_WINDOWS
 // G&N end
 
-				m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Copy Path to Clipboard","filetransferwindow"),this,TQT_SLOT(copyLocalFileToClipboard()));
+				m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Copy Path to Clipboard","filetransferwindow"),this,TQ_SLOT(copyLocalFileToClipboard()));
 
-				id = m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Delete file","filetransferwindow"),this,TQT_SLOT(deleteLocalFile()));
+				id = m_pLocalFilePopup->insertItem(__tr2qs_ctx("&Delete file","filetransferwindow"),this,TQ_SLOT(deleteLocalFile()));
 				m_pLocalFilePopup->setItemEnabled(id,i->transfer()->terminated());
 				m_pContextPopup->insertItem(__tr2qs_ctx("Local &File","filetransferwindow"),m_pLocalFilePopup);
 
@@ -399,14 +395,14 @@ void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const TQPo
 		item = (KviFileTransferItem *)item->nextSibling();
 	}
 
-	id = m_pContextPopup->insertItem(__tr2qs_ctx("&Clear Terminated","filetransferwindow"),this,TQT_SLOT(clearTerminated()));
+	id = m_pContextPopup->insertItem(__tr2qs_ctx("&Clear Terminated","filetransferwindow"),this,TQ_SLOT(clearTerminated()));
 	m_pContextPopup->setItemEnabled(id,bHaveTerminated);
 
 	bool bAreTransfersActive = false;
 	if(m_pListView->childCount() >= 1)
 		bAreTransfersActive = true;
 
-	id = m_pContextPopup->insertItem(__tr2qs_ctx("Clear &All","filetransferwindow"),this,TQT_SLOT(clearAll()));
+	id = m_pContextPopup->insertItem(__tr2qs_ctx("Clear &All","filetransferwindow"),this,TQ_SLOT(clearAll()));
 	m_pContextPopup->setItemEnabled(id,bAreTransfersActive);
 
 	m_pContextPopup->popup(pnt);
@@ -579,14 +575,10 @@ void KviFileTransferWindow::copyLocalFileToClipboard()
 	if(!t)return;
 	TQString tmp = t->localFileName();
 	if(tmp.isEmpty())return;
-#ifdef COMPILE_USE_QT4
-	TQApplication::clipboard()->setText(tmp);
-#else
 	TQApplication::clipboard()->setSelectionMode(false);
 	TQApplication::clipboard()->setText(tmp);
 	TQApplication::clipboard()->setSelectionMode(true);
 	TQApplication::clipboard()->setText(tmp);
-#endif
 }
 
 void KviFileTransferWindow::openLocalFileFolder()
