@@ -68,7 +68,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_mainwindow)
 
 bool KviKvsObject_mainwindow::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
-	setObject(TQT_TQOBJECT(new KviTalMainWindow(parentScriptWidget(), name())), true);
+	setObject(new KviTalMainWindow(parentScriptWidget(), name()), true);
 	return true;
 }
 
