@@ -181,8 +181,8 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_process,"process","object")
 KVSO_BEGIN_CONSTRUCTOR(KviKvsObject_process,KviKvsObject)
 
 	m_pProcess = new TQProcess();
-	connect(m_pProcess,TQT_SIGNAL(readyReadStdout()),this,TQT_SLOT(slotReadStdout()));
-	connect(m_pProcess,TQT_SIGNAL(readyReadStderr()),this,TQT_SLOT(slotReadStderr()));
+	connect(m_pProcess,TQ_SIGNAL(readyReadStdout()),this,TQ_SLOT(slotReadStdout()));
+	connect(m_pProcess,TQ_SIGNAL(readyReadStderr()),this,TQ_SLOT(slotReadStderr()));
 
 KVSO_END_CONSTRUCTOR(KviKvsObject_process)
 
@@ -261,7 +261,7 @@ bool KviKvsObject_process::functionclosekill(KviKvsObjectFunctionCall *c)
 	//I try to  to terminate the process the nice way....
 	m_pProcess->tryTerminate();
 	//If the process is still running after 5 seconds, I'll terminate the process in the hard way.
-	TQTimer::singleShot( 5000, m_pProcess, TQT_SLOT( kill() ) );
+	TQTimer::singleShot( 5000, m_pProcess, TQ_SLOT( kill() ) );
 	return true;
 }
 bool KviKvsObject_process::functionkill(KviKvsObjectFunctionCall *c)
