@@ -129,8 +129,8 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_toolbutton)
 
 bool KviKvsObject_toolbutton::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
 {
-	setObject(TQT_TQOBJECT(new TQToolButton(parentScriptWidget(), name())), true);
-	connect(widget(),TQT_SIGNAL(clicked()),this,TQT_SLOT(slotClicked()));
+	setObject(new TQToolButton(parentScriptWidget(), name()), true);
+	connect(widget(),TQ_SIGNAL(clicked()),this,TQ_SLOT(slotClicked()));
 	return true;
 }
 
