@@ -35,7 +35,7 @@
 
 class KviTextEncodingOptionsWidget : public KviOptionsWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KviTextEncodingOptionsWidget(TQWidget * parent);
