@@ -42,15 +42,7 @@
 
 #include <tqlayout.h>
 #include <tqlabel.h>
-#ifdef COMPILE_USE_QT4
-#include <tq3header.h>
-#include <tqevent.h>
-#include <TQImageWriter>
-#include <TQImageReader>
-
-#else
 #include <tqheader.h>
-#endif
 #include "kvi_pointerhashtable.h"
 #include <tqimage.h>
 #include <tqstring.h>
@@ -196,8 +188,8 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 		"Notify list fine-tuning can be performed by editing the entry properties.</center>"));
 #endif // COMPILE_INFO_TIPS
 
-	connect(m_pListView,TQT_SIGNAL(pressed(KviTalListViewItem *,const TQPoint &,int)),this,TQT_SLOT(itemPressed(KviTalListViewItem *,const TQPoint &,int)));
-	connect(m_pListView,TQT_SIGNAL(doubleClicked(KviTalListViewItem *)),this,TQT_SLOT(itemDoubleClicked(KviTalListViewItem *)));
+	connect(m_pListView,TQ_SIGNAL(pressed(KviTalListViewItem *,const TQPoint &,int)),this,TQ_SLOT(itemPressed(KviTalListViewItem *,const TQPoint &,int)));
+	connect(m_pListView,TQ_SIGNAL(doubleClicked(KviTalListViewItem *)),this,TQ_SLOT(itemDoubleClicked(KviTalListViewItem *)));
 
 	g->addMultiCellWidget(m_pListView,0,1,0,1);
 
@@ -206,7 +198,7 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 	g->addWidget(vbox,0,2);
 
 	m_pWizardAddButton = new TQPushButton(__tr2qs("Add (Wizard)..."),vbox);
-	connect(m_pWizardAddButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(addWizardClicked()));
+	connect(m_pWizardAddButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(addWizardClicked()));
 #ifdef COMPILE_INFO_TIPS
 	TQToolTip::add(m_pWizardAddButton,__tr2qs("Add a registered user by means of a user-friendly wizard."));
 #endif // COMPILE_INFO_TIPS
@@ -214,21 +206,21 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 
 
 	m_pAddButton = new TQPushButton(__tr2qs("&Add..."),vbox);
-	connect(m_pAddButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(addClicked()));
+	connect(m_pAddButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(addClicked()));
 #ifdef COMPILE_INFO_TIPS
 	TQToolTip::add(m_pAddButton,__tr2qs("Open the edit dialog to create a new user entry."));
 #endif // COMPILE_INFO_TIPS
 	m_pAddButton->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_NEWITEM)));
 	
 	m_pAddGroupButton = new TQPushButton(__tr2qs("&Add Group..."),vbox);
-	connect(m_pAddGroupButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(addGroupClicked()));
+	connect(m_pAddGroupButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(addGroupClicked()));
 #ifdef COMPILE_INFO_TIPS
 	TQToolTip::add(m_pAddGroupButton,__tr2qs("Adds a new group"));
 #endif // COMPILE_INFO_TIPS
 	m_pAddGroupButton->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_NEWITEM)));
 
 	m_pRemoveButton = new TQPushButton(__tr2qs("Re&move"),vbox);
-	connect(m_pRemoveButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(removeClicked()));
+	connect(m_pRemoveButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(removeClicked()));
 	m_pRemoveButton->setEnabled(false);
 #ifdef COMPILE_INFO_TIPS
 	TQToolTip::add(m_pRemoveButton,__tr2qs("Remove the currently selected entries."));
@@ -237,7 +229,7 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 
 
 	m_pEditButton = new TQPushButton(__tr2qs("&Edit..."),vbox);
-	connect(m_pEditButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(editClicked()));
+	connect(m_pEditButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(editClicked()));
 	m_pEditButton->setEnabled(false);
 #ifdef COMPILE_INFO_TIPS
 	TQToolTip::add(m_pEditButton,__tr2qs("Edit the first selected entry."));
@@ -249,7 +241,7 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 
 	m_pExportButton = new TQPushButton(__tr("Export To..."),vbox);
 	m_pExportButton->setEnabled(false);
-	connect(m_pExportButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(exportClicked()));
+	connect(m_pExportButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(exportClicked()));
 #ifdef COMPILE_INFO_TIPS
 	TQToolTip::add(m_pExportButton,__tr2qs("Export the selected entries to a file.<br>All the data associated with the selected registered users will be exported.<br>You (or anyone else) can later import the entries by using the \"Import\" button."));
 #endif // COMPILE_INFO_TIPS
@@ -257,7 +249,7 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 
 
 	m_pImportButton = new TQPushButton(__tr("Import From..."),vbox);
-	connect(m_pImportButton,TQT_SIGNAL(clicked()),this,TQT_SLOT(importClicked()));
+	connect(m_pImportButton,TQ_SIGNAL(clicked()),this,TQ_SLOT(importClicked()));
 #ifdef COMPILE_INFO_TIPS
 	TQToolTip::add(m_pImportButton,__tr2qs("Import entries from a file exported earlier by the \"export\" function of this dialog."));
 #endif // COMPILE_INFO_TIPS
@@ -272,12 +264,12 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 
 
 	b = new TQPushButton(__tr2qs("&OK"),hbox);
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(okClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(okClicked()));
 	b->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_ACCEPT)));
 	//b->setMinimumWidth(120);
 
 	b = new TQPushButton(__tr2qs("Cancel"),hbox);
-	connect(b,TQT_SIGNAL(clicked()),this,TQT_SLOT(cancelClicked()));
+	connect(b,TQ_SIGNAL(clicked()),this,TQ_SLOT(cancelClicked()));
 	b->setIconSet(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_DISCARD)));
 	//b->setMinimumWidth(120);
 
@@ -287,8 +279,8 @@ KviRegisteredUsersDialog::KviRegisteredUsersDialog(TQWidget * par)
 	g->setColStretch(0,1);
 	g->setRowStretch(1,1);
 
-	connect(m_pListView,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(selectionChanged()));
-	connect(m_pListView,TQT_SIGNAL(rightButtonClicked ( KviTalListViewItem *, const TQPoint &, int ) ),this,TQT_SLOT(listViewRightButtonClicked ( KviTalListViewItem *, const TQPoint &, int )));
+	connect(m_pListView,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(selectionChanged()));
+	connect(m_pListView,TQ_SIGNAL(rightButtonClicked ( KviTalListViewItem *, const TQPoint &, int ) ),this,TQ_SLOT(listViewRightButtonClicked ( KviTalListViewItem *, const TQPoint &, int )));
 
 	fillList();
 
@@ -436,7 +428,7 @@ void KviRegisteredUsersDialog::listViewRightButtonClicked ( KviTalListViewItem *
 				m_TmpDict.replace(id,g->data());
 			}
 			
-			connect(groups,TQT_SIGNAL(activated ( int )),this,TQT_SLOT(moveToGroupMenuClicked(int)));
+			connect(groups,TQ_SIGNAL(activated ( int )),this,TQ_SLOT(moveToGroupMenuClicked(int)));
 			
 			KviTalPopupMenu *mainPopup = new KviTalPopupMenu;
 			mainPopup->insertItem(__tr("Move to group"),groups);
@@ -740,18 +732,11 @@ void KviRegisteredUsersDialog::exportClicked()
 					if(!av->pixmap()->isNull())
 					{
 						if(!f.save(1))goto write_error;
-#ifdef COMPILE_USE_QT4
-						TQImageWriter io;
-						io.setDevice(&f);
-						io.setFormat("PNG");						
-						if(!io.write(av->pixmap()->convertToImage()))goto write_error;
-#else
 						TQImageIO io;
 						io.setImage(av->pixmap()->convertToImage());
-						io.setIODevice(TQT_TQIODEVICE(&f));
+						io.setIODevice(&f);
 						io.setFormat("PNG");
 						if(!io.write())goto write_error;
-#endif	
 					} else {
 						if(!f.save(0))goto write_error;
 					}
@@ -845,23 +830,14 @@ void KviRegisteredUsersDialog::importClicked()
 		{
 			// there is an avatar
 			TQImage img;
-#ifdef COMPILE_USE_QT4
-			TQImageReader io;
-			io.setDevice(&f);
-			io.setFormat("PNG");
-			img=io.read();
-//			if(io.read())goto read_error;
-
-#else
 			TQImageIO io;
 			io.setImage(img);
-			io.setIODevice(TQT_TQIODEVICE(&f));
+			io.setIODevice(&f);
 			io.setFormat("PNG");
 
 			if(!io.read())goto read_error;
 
 			img = io.image();
-#endif
 			if(img.isNull())tqDebug("Ops.. readed a null image ?");
 
 			KviStr fName = u->name();
@@ -898,6 +874,3 @@ succesfull_import:
 	f.close();
 	fillList();
 }
-#if defined(COMPILE_USE_QT4) && defined(COMPILE_ON_WINDOWS) 
-#include "dialog.moc"
-#endif
