@@ -31,9 +31,6 @@
 #include "kvi_pixmap.h"
 #include "kvi_regusersdb.h"
 #include "kvi_iconmanager.h"
-#ifdef COMPILE_USE_QT4
-#include <TQDesktopWidget>
-#endif
 
 #include <tqcheckbox.h>
 #include <tqlabel.h>
@@ -98,7 +95,7 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
 
 	if(mask.nick() != "*")m_pEditRealName->setText(mask.nick());
 
-	connect(m_pEditRealName,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(realNameChanged(const TQString &)));
+	connect(m_pEditRealName,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(realNameChanged(const TQString &)));
 
 	// PAGE 2
 
@@ -122,18 +119,18 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
     m_pNicknameEdit1 = new TQLineEdit(m_pPage2);
     m_pNicknameEdit1->setAlignment(TQt::AlignRight);
 	if(mask.nick() != "*")m_pNicknameEdit1->setText(mask.nick());
-	connect(m_pNicknameEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(maskChanged(const TQString &)));
+	connect(m_pNicknameEdit1,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(maskChanged(const TQString &)));
     m_pPage2Layout->addWidget( m_pNicknameEdit1, 1, 0 );
 
     m_pUsernameEdit1 = new TQLineEdit(m_pPage2);
     m_pUsernameEdit1->setAlignment(TQt::AlignHCenter);
 	if(mask.hasUser())m_pUsernameEdit1->setText(mask.user());
-	connect(m_pUsernameEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(maskChanged(const TQString &)));
+	connect(m_pUsernameEdit1,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(maskChanged(const TQString &)));
     m_pPage2Layout->addWidget(m_pUsernameEdit1,1,2);
 
 	m_pHostEdit1 = new TQLineEdit(m_pPage2);
 	if(mask.hasHost())m_pHostEdit1->setText(mask.host());
-	connect(m_pHostEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(maskChanged(const TQString &)));
+	connect(m_pHostEdit1,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(maskChanged(const TQString &)));
 	m_pPage2Layout->addWidget(m_pHostEdit1,1,4);
 
     m_pNicknameEdit2 = new TQLineEdit(m_pPage2);
@@ -214,7 +211,7 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
     m_pNotifyCheck = new TQCheckBox(m_pPage4);
     m_pNotifyCheck->setText(__tr2qs("Add this user to the notify list"));
 	m_pNotifyCheck->setChecked(false);
-	connect(m_pNotifyCheck,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(notifyCheckToggled(bool)));
+	connect(m_pNotifyCheck,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(notifyCheckToggled(bool)));
     m_pPage4Layout->addMultiCellWidget(m_pNotifyCheck,2,2,0,1);
 
     m_pNotifyNickLabel1 = new TQLabel(m_pPage4);
@@ -227,11 +224,11 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
 
     m_pNotifyNickEdit1 = new TQLineEdit(m_pPage4);
 	if(mask.nick() != "*")m_pNotifyNickEdit1->setText(mask.nick());
-	connect(m_pNotifyNickEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(notifyNickChanged(const TQString &)));
+	connect(m_pNotifyNickEdit1,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(notifyNickChanged(const TQString &)));
     m_pPage4Layout->addWidget(m_pNotifyNickEdit1,3,1);
 
     m_pNotifyNickEdit2 = new TQLineEdit(m_pPage4);
-	connect(m_pNotifyNickEdit2,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(notifyNickChanged(const TQString &)));
+	connect(m_pNotifyNickEdit2,TQ_SIGNAL(textChanged(const TQString &)),this,TQ_SLOT(notifyNickChanged(const TQString &)));
     m_pPage4Layout->addWidget(m_pNotifyNickEdit2,4,1);
 
 	m_pPage4Layout->setRowStretch(0,1);
